pub struct FileSystemResolver { /* private fields */ }Expand description
Resolves files from the file system.
Files are resolved relative to root and cannot escape it.
Implementations
Sourceimpl FileSystemResolver
impl FileSystemResolver
Sourcepub fn new(root: PathBuf) -> Self
pub fn new(root: PathBuf) -> Self
Creates a new file system resolver with the given root directory.
Example
let resolver = FileSystemResolver::new("./templates".into());Sourcepub fn with_local_package_root(self, path: PathBuf) -> Self
👎Deprecated since 0.14.1: Use FileSystemResolver::local_package_root instead
pub fn with_local_package_root(self, path: PathBuf) -> Self
FileSystemResolver::local_package_root insteadSets a custom path for local packages.
Sourcepub fn local_package_root(self, local_package_root: PathBuf) -> Self
pub fn local_package_root(self, local_package_root: PathBuf) -> Self
Sets a custom path for local packages.
Example
let resolver = FileSystemResolver::new("./templates".into())
.local_package_root("./local-packages".into());Trait Implementations
Sourceimpl Clone for FileSystemResolver
impl Clone for FileSystemResolver
Sourcefn clone(&self) -> FileSystemResolver
fn clone(&self) -> FileSystemResolver
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileSystemResolver
impl Debug for FileSystemResolver
Sourceimpl FileResolver for FileSystemResolver
impl FileResolver for FileSystemResolver
Sourcefn resolve_binary(&self, id: FileId) -> FileResult<Cow<'_, Bytes>>
fn resolve_binary(&self, id: FileId) -> FileResult<Cow<'_, Bytes>>
Resolves a binary file (e.g., images, fonts).
Sourcefn resolve_source(&self, id: FileId) -> FileResult<Cow<'_, Source>>
fn resolve_source(&self, id: FileId) -> FileResult<Cow<'_, Source>>
Resolves a source file (e.g.,
.typ files).Sourceimpl IntoCachedFileResolver for FileSystemResolver
impl IntoCachedFileResolver for FileSystemResolver
Sourcefn into_cached(self) -> CachedFileResolver<Self>
fn into_cached(self) -> CachedFileResolver<Self>
Wraps this resolver with caching.