pub struct TypstEngine<T = TypstTemplateCollection> { /* private fields */ }Expand description
Main entry point for compiling Typst documents.
Use TypstEngine::builder() to construct an instance. You can optionally set a
main file with main_file(), which allows
compiling without specifying the file ID each time.
Examples
With main file (compile without file ID):
static TEMPLATE: &str = "Hello World!";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.main_file(TEMPLATE)
.fonts([FONT])
.build();
// Compile the main file directly
let doc: PagedDocument = engine.compile().output.expect("Compilation failed");Without main file (must provide file ID):
static TEMPLATE: &str = "Hello World!";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.fonts([FONT])
.with_static_source_file_resolver([("template.typ", TEMPLATE)])
.build();
// Must specify file ID for each compile
let doc: PagedDocument = engine.compile("template.typ").output.expect("Compilation failed");See also: Examples directory
Implementations
Sourceimpl TypstEngine<TypstTemplateCollection>
impl TypstEngine<TypstTemplateCollection>
Sourcepub fn builder() -> TypstTemplateEngineBuilder
pub fn builder() -> TypstTemplateEngineBuilder
Creates a new builder for configuring a TypstEngine.
Example
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.fonts([FONT])
.build();Sourceimpl TypstEngine<TypstTemplateCollection>
impl TypstEngine<TypstTemplateCollection>
Sourcepub fn compile_with_input<F, D, Doc>(
&self,
main_source_id: F,
inputs: D,
) -> Warned<Result<Doc, TypstAsLibError>>
pub fn compile_with_input<F, D, Doc>( &self, main_source_id: F, inputs: D, ) -> Warned<Result<Doc, TypstAsLibError>>
Compiles a Typst document with input data injected as sys.inputs.
The input will be available in Typst scripts via #import sys: inputs.
To change the injection location, use custom_inject_location().
Example
static TEMPLATE: &str = "#import sys: inputs\n#inputs.name";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.fonts([FONT])
.with_static_source_file_resolver([("main.typ", TEMPLATE)])
.build();
let mut inputs = Dict::new();
inputs.insert("name".into(), "World".into_value());
let doc: PagedDocument = engine.compile_with_input("main.typ", inputs)
.output
.expect("Compilation failed");See also: resolve_static.rs
Sourcepub fn compile<F, Doc>(
&self,
main_source_id: F,
) -> Warned<Result<Doc, TypstAsLibError>>where
F: IntoFileId,
Doc: Document,
pub fn compile<F, Doc>(
&self,
main_source_id: F,
) -> Warned<Result<Doc, TypstAsLibError>>where
F: IntoFileId,
Doc: Document,
Compiles a Typst document without input data.
Sourceimpl TypstEngine<TypstTemplateMainFile>
impl TypstEngine<TypstTemplateMainFile>
Sourcepub fn compile_with_input<D, Doc>(
&self,
inputs: D,
) -> Warned<Result<Doc, TypstAsLibError>>
pub fn compile_with_input<D, Doc>( &self, inputs: D, ) -> Warned<Result<Doc, TypstAsLibError>>
Compiles the main file with input data injected as sys.inputs.
The input will be available in Typst scripts via #import sys: inputs.
To change the injection location, use custom_inject_location().
Example
static TEMPLATE: &str = "#import sys: inputs\nHello #inputs.name!";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.main_file(TEMPLATE)
.fonts([FONT])
.build();
let mut inputs = Dict::new();
inputs.insert("name".into(), "World".into_value());
let doc: PagedDocument = engine.compile_with_input(inputs)
.output
.expect("Compilation failed");See also: small_example.rs