pub struct TypstTemplateEngineBuilder<T = TypstTemplateCollection> { /* private fields */ }Expand description
Builder for constructing a TypstEngine.
Implementations
Sourceimpl TypstTemplateEngineBuilder<TypstTemplateCollection>
impl TypstTemplateEngineBuilder<TypstTemplateCollection>
Sourcepub fn main_file<S: IntoSource>(
self,
source: S,
) -> TypstTemplateEngineBuilder<TypstTemplateMainFile>
pub fn main_file<S: IntoSource>( self, source: S, ) -> TypstTemplateEngineBuilder<TypstTemplateMainFile>
Sets the main file for compilation.
This is optional. If not set, you must provide a file ID on each compile call.
Example
static TEMPLATE: &str = "Hello World!";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.main_file(TEMPLATE)
.fonts([FONT])
.build();
let doc: PagedDocument = engine.compile().output.expect("Compilation failed");See also: small_example.rs
Sourceimpl<T> TypstTemplateEngineBuilder<T>
impl<T> TypstTemplateEngineBuilder<T>
Sourcepub fn custom_inject_location(
self,
module_name: &'static str,
value_name: &'static str,
) -> Self
pub fn custom_inject_location( self, module_name: &'static str, value_name: &'static str, ) -> Self
Customizes where input data is injected in the Typst environment.
By default, inputs are available as sys.inputs.
Sourcepub fn fonts<I, F>(self, fonts: I) -> Selfwhere
I: IntoIterator<Item = F>,
F: IntoFonts,
pub fn fonts<I, F>(self, fonts: I) -> Selfwhere
I: IntoIterator<Item = F>,
F: IntoFonts,
Adds fonts for rendering.
Accepts font data as &[u8], Vec<u8>, Bytes, or Font.
For automatic system font discovery, see typst-kit-fonts feature.
Example
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.fonts([FONT])
.build();Sourcepub fn add_file_resolver<F>(self, file_resolver: F) -> Self
pub fn add_file_resolver<F>(self, file_resolver: F) -> Self
Adds a custom file resolver.
Resolvers are tried in order until one successfully resolves the file.
Sourcepub fn with_static_source_file_resolver<IS, S>(self, sources: IS) -> Selfwhere
IS: IntoIterator<Item = S>,
S: IntoSource,
pub fn with_static_source_file_resolver<IS, S>(self, sources: IS) -> Selfwhere
IS: IntoIterator<Item = S>,
S: IntoSource,
Adds static source files embedded in memory.
Accepts sources as &str, String, (&str, &str) (path, content),
(FileId, &str), or Source.
Example
static MAIN: &str = "#import \"lib.typ\": greet\n#greet()";
static LIB: &str = "#let greet() = [Hello World!]";
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.fonts([FONT])
.with_static_source_file_resolver([
("main.typ", MAIN),
("lib.typ", LIB),
])
.build();
let doc: PagedDocument = engine.compile("main.typ").output.expect("Compilation failed");See also: resolve_static.rs
Sourcepub fn with_static_file_resolver<IB, F, B>(self, binaries: IB) -> Self
pub fn with_static_file_resolver<IB, F, B>(self, binaries: IB) -> Self
Adds static binary files embedded in memory (e.g., images).
Example
static TEMPLATE: &str = r#"#image("logo.png")"#;
static LOGO: &[u8] = include_bytes!("../examples/templates/images/typst.png");
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.main_file(TEMPLATE)
.fonts([FONT])
.with_static_file_resolver([("logo.png", LOGO)])
.build();See also: resolve_static.rs
Sourcepub fn with_file_system_resolver<P>(self, root: P) -> Self
pub fn with_file_system_resolver<P>(self, root: P) -> Self
Enables loading files from the file system.
Files are resolved relative to root. Files outside of root cannot be accessed.
Example
static TEMPLATE: &str = r#"#include "header.typ""#;
static FONT: &[u8] = include_bytes!("../examples/fonts/texgyrecursor-regular.otf");
let engine = TypstEngine::builder()
.main_file(TEMPLATE)
.fonts([FONT])
.with_file_system_resolver("./templates")
.build();See also: resolve_packages.rs
Sourcepub fn comemo_evict_max_age(
&mut self,
comemo_evict_max_age: Option<usize>,
) -> &mut Self
pub fn comemo_evict_max_age( &mut self, comemo_evict_max_age: Option<usize>, ) -> &mut Self
Sets the maximum age for comemo cache eviction after compilation.
Default is Some(0), which evicts after each compilation.
Sourcepub fn build(self) -> TypstEngine<T>
pub fn build(self) -> TypstEngine<T>
Builds the TypstEngine with the configured options.